import csv
from datetime import datetime
from tt.db import initialize_db, Task, Category
from tt.config import STATUSES


def import_tasks_from_csv(filename: str):
    initialize_db()

    with open(filename, "r") as f:
        reader = csv.DictReader(f)

        for row in reader:
            # Parse the due date if it exists and isn't empty
            due_date = None
            if row["due"] and row["due"].strip():
                try:
                    due_date = datetime.strptime(row["due"].strip(), "%Y-%m-%d")
                except ValueError:
                    print(f"Warning: Couldn't parse '{row['due']}', skipping due date")

            # Validate status
            status = row["status"].lower() if row["status"] else "zero"
            if status not in STATUSES:
                print(f"Warning: Invalid status '{status}', defaulting to 'zero'")
                status = "zero"

            category_id = None
            if row["category"].strip():
                category_name = row["category"].strip()
                category, _ = Category.get_or_create(
                    name=category_name, defaults={"description": None}
                )
                category_id = category.id

            Task.create(
                text=row["task"],
                type=row["type"],
                status=status,
                due=due_date,
                category_id=category_id,
            )
            print(f"Imported task: {row['task']}")
