import json

from ..controller.generators import (
    get_generator,
    get_generators,
    add_generator,
    update_generator,
    generate_needed_tasks,
)
from ..db import GeneratorType
from .editor import (
    TableEditor,
    TableColumnConfig,
    EnumColumnConfig,
)


class TaskGenEditor(TableEditor):
    TABLE_CONFIG = (
        TableColumnConfig("id", "ID"),
        TableColumnConfig("template", "Template", default="recur {val}"),
        EnumColumnConfig(
            "type",
            "Type",
            default=GeneratorType.DAYS_BETWEEN.value,
            enum=GeneratorType,
        ),
        TableColumnConfig("val", "Value", default="1"),
        TableColumnConfig("next_at", "Next @", read_only=True),
    )

    def __init__(self):
        super().__init__()
        self.update_item_callback = update_generator
        self.add_item_callback = add_generator
        self.get_item_callback = get_generator

    def refresh_items(self):
        generated = generate_needed_tasks()
        if num := len(generated):
            self.notify(f"created {num} tasks")
        items = get_generators()
        for item in items:
            self.table.add_row(
                str(item.id),
                item.template,
                item.type,
                json.loads(item.config)["val"],
                str(item.next_at()),
            )


def run():
    app = TaskGenEditor()
    app.run()
